@@ -1,8 +1,8 @@
 /* Copyright 2004 Roger Dingledine */
 /* Copyright 2004-2005 Roger Dingledine, Nick Mathewson */
 /* See LICENSE for licensing information */
-/* $Id: torgzip.c,v 1.15 2005/04/01 20:15:54 nickm Exp $ */
-const char torgzip_c_id[] = "$Id: torgzip.c,v 1.15 2005/04/01 20:15:54 nickm Exp $";
+/* $Id: torgzip.c,v 1.16 2005/05/07 05:55:05 nickm Exp $ */
+const char torgzip_c_id[] = "$Id: torgzip.c,v 1.16 2005/05/07 05:55:05 nickm Exp $";
 
 /**
  * \file torgzip.c
@@ -94,7 +94,7 @@ tor_gzip_compress(char **out, size_t *out_len,
   out_size = in_len / 2;
   if (out_size < 1024) out_size = 1024;
   *out = tor_malloc(out_size);
-  stream->next_out = *out;
+  stream->next_out = (unsigned char*)*out;
   stream->avail_out = out_size;
 
   while (1) {
@@ -110,7 +110,7 @@ tor_gzip_compress(char **out, size_t *out_len,
         offset = stream->next_out - ((unsigned char*)*out);
         out_size *= 2;
         *out = tor_realloc(*out, out_size);
-        stream->next_out = *out + offset;
+        stream->next_out = (unsigned char*)(*out + offset);
         stream->avail_out = out_size - offset;
         break;
       default:
@@ -179,7 +179,7 @@ tor_gzip_uncompress(char **out, size_t *out_len,
   if (out_size < 1024) out_size = 1024;
 
   *out = tor_malloc(out_size);
-  stream->next_out = *out;
+  stream->next_out = (unsigned char*)*out;
   stream->avail_out = out_size;
 
   while (1) {
@@ -195,7 +195,7 @@ tor_gzip_uncompress(char **out, size_t *out_len,
         offset = stream->next_out - ((unsigned char*)*out);
         out_size *= 2;
         *out = tor_realloc(*out, out_size);
-        stream->next_out = *out + offset;
+        stream->next_out = (unsigned char*)(*out + offset);
         stream->avail_out = out_size - offset;
         break;
       default:
