@@ -2,8 +2,8 @@
  * Copyright 2001-2004 Roger Dingledine.
  * Copyright 2004-2005 Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: main.c,v 1.505.2.2 2005/06/07 17:34:40 nickm Exp $ */
-const char main_c_id[] = "$Id: main.c,v 1.505.2.2 2005/06/07 17:34:40 nickm Exp $";
+/* $Id: main.c,v 1.505.2.3 2005/06/13 00:48:39 nickm Exp $ */
+const char main_c_id[] = "$Id: main.c,v 1.505.2.3 2005/06/13 00:48:39 nickm Exp $";
 
 /**
  * \file main.c
@@ -769,6 +769,7 @@ static void run_scheduled_events(time_t now) {
 }
 
 static struct event *timeout_event = NULL;
+static int n_libevent_errors = 0;
 
 /** Libevent callback: invoked once every second. */
 static void second_elapsed_callback(int fd, short event, void *args)
@@ -840,6 +841,19 @@ static void second_elapsed_callback(int fd, short event, void *args)
            "Error from libevent when setting one-second timeout event");
 }
 
+/** Called when a possibly ignorable libevent error occurs; ensures that we
+ * don't get into an infinite loop by ignoring too many errors from
+ * libevent. */
+int
+got_libevent_error(void)
+{
+  if (++n_libevent_errors > 8) {
+    log_fn(LOG_ERR, "Too many libevent errors in one second; dying");
+    return -1;
+  }
+  return 0;
+}
+
 /** Called when we get a SIGHUP: reload configuration files and keys,
  * retry all connections, re-upload all descriptors, and so on. */
 static int do_hup(void) {
@@ -952,6 +966,12 @@ static int do_main_loop(void) {
                tor_socket_strerror(e), e);
 #endif
         return -1;
+#ifndef MS_WINDOWS
+      } else if (e == EINVAL) {
+        log_fn(LOG_WARN, "EINVAL from libevent: should you upgrade libevent?");
+        if (got_libevent_error())
+          return -1;
+#endif
       } else {
         if (ERRNO_IS_EINPROGRESS(e))
           log_fn(LOG_WARN,"libevent poll returned EINPROGRESS? Please report.");
