@@ -2,8 +2,8 @@
  * Copyright 2001-2004 Roger Dingledine.
  * Copyright 2004-2005 Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: router.c,v 1.175 2005/05/23 05:20:52 arma Exp $ */
-const char router_c_id[] = "$Id: router.c,v 1.175 2005/05/23 05:20:52 arma Exp $";
+/* $Id: router.c,v 1.176.2.2 2005/06/09 21:26:46 arma Exp $ */
+const char router_c_id[] = "$Id: router.c,v 1.176.2.2 2005/06/09 21:26:46 arma Exp $";
 
 #include "or.h"
 
@@ -405,7 +405,7 @@ void consider_testing_reachability(void) {
     if (me) {
       directory_initiate_command_router(me, DIR_PURPOSE_FETCH_DIR, 1, NULL, NULL, 0);
     } else {
-      log_fn(LOG_NOTICE,"Delaying checking DirPort reachability; can't build descriptor.");
+      log(LOG_NOTICE,"Delaying checking DirPort reachability; can't build descriptor.");
     }
   }
 }
@@ -414,7 +414,8 @@ void consider_testing_reachability(void) {
 void router_orport_found_reachable(void) {
   if (!can_reach_or_port) {
     if (!clique_mode(get_options()))
-      log_fn(LOG_NOTICE,"Your ORPort is reachable from the outside. Excellent. Publishing server descriptor.");
+      log(LOG_NOTICE,"Your ORPort is reachable from the outside. Excellent.%s",
+          get_options()->NoPublish ? "" : " Publishing server descriptor.");
     can_reach_or_port = 1;
     consider_publishable_server(time(NULL), 1);
   }
@@ -423,7 +424,7 @@ void router_orport_found_reachable(void) {
 /** Annotate that we found our DirPort reachable. */
 void router_dirport_found_reachable(void) {
   if (!can_reach_dir_port) {
-    log_fn(LOG_NOTICE,"Your DirPort is reachable from the outside. Excellent.");
+    log(LOG_NOTICE,"Your DirPort is reachable from the outside. Excellent.");
     can_reach_dir_port = 1;
   }
 }
@@ -451,6 +452,7 @@ int clique_mode(or_options_t *options) {
 /** Return true iff we are trying to be a server.
  */
 int server_mode(or_options_t *options) {
+  if (options->ClientOnly) return 0;
   return (options->ORPort != 0 || options->ORBindAddress);
 }
 
